summaryrefslogtreecommitdiff
path: root/framework/inc/framework/framelistanalyzer.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'framework/inc/framework/framelistanalyzer.hxx')
-rw-r--r--framework/inc/framework/framelistanalyzer.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/framework/inc/framework/framelistanalyzer.hxx b/framework/inc/framework/framelistanalyzer.hxx
index 12e063c0d53f..951474c3934d 100644
--- a/framework/inc/framework/framelistanalyzer.hxx
+++ b/framework/inc/framework/framelistanalyzer.hxx
@@ -42,7 +42,7 @@ class FWE_DLLPUBLIC FrameListAnalyzer
/** These enums can be combined as flags to enable/disable
special search algorithm during analyze phase.
- see impl_analyze() for further informations.
+ see impl_analyze() for further information.
But note: To be useable as flags, these enums
must be values of range [2^n]! */
enum EDetect
@@ -67,7 +67,7 @@ class FWE_DLLPUBLIC FrameListAnalyzer
const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& m_xReferenceFrame;
/** enable/disable some special analyzing steps.
- see impl_analyze() for further informations. */
+ see impl_analyze() for further information. */
sal_uInt32 m_eDetectMode;
/** contains all frames, which uses the same model like the reference frame.
@@ -157,7 +157,7 @@ class FWE_DLLPUBLIC FrameListAnalyzer
public:
/** starts analyze phase and fille all members with valid informations.
@param xSupplier
Must be a valid reference to a frames supplier, which provies
@@ -157,7 +157,7 @@ class FWE_DLLPUBLIC FrameListAnalyzer
public:
- /** starts analyze phase and fille all members with valid informations.
+ /** starts analyze phase and fille all members with valid information.
Must be a valid reference to a frames supplier, which provies